==> kpogre-1.2.7.tar.gz: kpogre-1.2.7/kpogre/DbObjects/kpgoperatorsfolder.cpp <==
//
// C++ Implementation: kpgoperatorsfolder
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgoperatorsfolder.h"

// include files for KDE
#include <kdebug.h>
#include <kmessagebox.h>
#include <klocale.h>

#include <qtable.h>

#include "kpgconnection.h"
#include "kpgschema.h"
#include "../PropertyPages/kpgpropertypage.h"
#include "kpgoperator.h"
#include "../kpgsqldialog.h"

KPGOperatorsFolder::KPGOperatorsFolder(KPGSchema *parent, pqxx::oid oidNameSpace)
 : KPGItemsFolder(parent, i18n("Operators"))
{
	setPixmap(0, *m_pIconFolderYellow);
	m_oidNameSpace = oidNameSpace;
}


KPGOperatorsFolder::~KPGOperatorsFolder()
{
}

bool KPGOperatorsFolder::refresh(pqxx::work &pqxxXaction)
{
  // delete all child items 
  while (QListViewItem * pItem = firstChild())
    delete pItem;

	// obtain list of operators
  QString strQuery("SELECT op.oid, op.oprname, description, op.oprkind, op.oprcanhash, op.oprleft, lt.typname as lefttype, op.oprright, rt.typname as righttype, op.oprresult, ret.typname as resulttype, op.oprcom, co.oprname as compop, op.oprnegate, ne.oprname as negop, op.oprlsortop, lso.oprname as leftsortop, op.oprrsortop, rso.oprname as rightsortop, op.oprltcmpop, lco.oprname as lessthancmpop, op.oprgtcmpop, gco.oprname as greatherthancmpop,  op.oprcode::oid AS oprcodeoid, op.oprcode as operproc, op.oprrest::oid AS oprrestoid, op.oprrest as restrproc, op.oprjoin::oid AS oprjoinoid, op.oprjoin as joinproc, pg_get_userbyid(op.oprowner) as opowner ");
		
	strQuery.append("FROM pg_operator op ");
	strQuery.append("LEFT OUTER JOIN pg_type lt ON lt.oid=op.oprleft ");
	strQuery.append("LEFT OUTER JOIN pg_type rt ON rt.oid=op.oprright ");
	strQuery.append("JOIN pg_type ret on ret.oid=op.oprresult ");
	strQuery.append("LEFT OUTER JOIN pg_description des ON des.objoid=op.oid ");
	strQuery.append("LEFT OUTER JOIN pg_operator co ON co.oid=op.oprcom ");
	strQuery.append("LEFT OUTER JOIN pg_operator ne ON ne.oid=op.oprnegate ");
	strQuery.append("LEFT OUTER JOIN pg_operator lso ON lso.oid=op.oprlsortop ");
	strQuery.append("LEFT OUTER JOIN pg_operator rso ON rso.oid=op.oprrsortop ");
	strQuery.append("LEFT OUTER JOIN pg_operator lco ON lco.oid=op.oprltcmpop ");
	strQuery.append("LEFT OUTER JOIN pg_operator gco ON gco.oid=op.oprgtcmpop ");
	strQuery.append("WHERE op.oprnamespace = " + QString("%1").arg(m_oidNameSpace) + " ");
	strQuery.append("ORDER BY op.oprname");
			
  try
  {
    m_pqxxResultOperators = pqxxXaction.Exec(strQuery.latin1());

		KPGOperator *pgOperator = 0;
		
    for (result::size_type i = 0; i != m_pqxxResultOperators.size(); ++i)
    {
			pqxx::oid oid;
			m_pqxxResultOperators[i][0].to(oid);
		
			if(pgOperator == 0)
      	pgOperator = new KPGOperator(this, m_pqxxResultOperators[i]["oprname"].c_str(), oid);
			else
				pgOperator = new KPGOperator(this, pgOperator, m_pqxxResultOperators[i]["oprname"].c_str(), oid);
			
			bool bCanHash;
			pqxx::oid oidLeftType = 0;
			pqxx::oid oidRightType = 0;
			pqxx::oid oidResultType = 0;
			
			pqxx::oid oidComutatorOpr = 0;
			pqxx::oid oidNegatorOpr = 0;
			pqxx::oid oidLeftSortOpr = 0;
			pqxx::oid oidRightSortOpr = 0;
			pqxx::oid oidLessThanOpr = 0;
			pqxx::oid oidGreatherThanOpr = 0;
			
			pqxx::oid oidOperatorFunc = 0;
			pqxx::oid oidRestrictionFunc = 0;
			pqxx::oid oidJoinFunc = 0;
			
			m_pqxxResultOperators[i]["oprcanhash"].to(bCanHash);
			m_pqxxResultOperators[i]["oprleft"].to(oidLeftType);
			m_pqxxResultOperators[i]["oprright"].to(oidRightType);
			m_pqxxResultOperators[i]["oprresult"].to(oidResultType);
			
			m_pqxxResultOperators[i]["oprcom"].to(oidComutatorOpr);
			m_pqxxResultOperators[i]["oprnegate"].to(oidNegatorOpr);
			m_pqxxResultOperators[i]["oprlsortop"].to(oidLeftSortOpr);
			m_pqxxResultOperators[i]["oprrsortop"].to(oidRightSortOpr);
			m_pqxxResultOperators[i]["oprltcmpop"].to(oidLessThanOpr);
			m_pqxxResultOperators[i]["oprgtcmpop"].to(oidGreatherThanOpr);
			
			m_pqxxResultOperators[i]["oprcodeoid"].to(oidOperatorFunc);
			m_pqxxResultOperators[i]["oprrestoid"].to(oidRestrictionFunc);
			m_pqxxResultOperators[i]["oprjoinoid"].to(oidJoinFunc);
			
					
			pgOperator->setProperties(
				m_pqxxResultOperators[i]["description"].c_str(),
				m_pqxxResultOperators[i]["opowner"].c_str(),
				m_pqxxResultOperators[i]["oprkind"].c_str(),
				bCanHash,
				oidLeftType,
				m_pqxxResultOperators[i]["lefttype"].c_str(),
				oidRightType,
				m_pqxxResultOperators[i]["righttype"].c_str(),
				oidResultType,
				m_pqxxResultOperators[i]["resulttype"].c_str(),
				oidComutatorOpr,
				m_pqxxResultOperators[i]["compop"].c_str(),
				oidNegatorOpr,
				m_pqxxResultOperators[i]["negop"].c_str(),
				oidLeftSortOpr,
				m_pqxxResultOperators[i]["leftsortop"].c_str(),
				oidRightSortOpr,
				m_pqxxResultOperators[i]["rightsortop"].c_str(),
				oidLessThanOpr,
				m_pqxxResultOperators[i]["lessthancmpop"].c_str(),
				oidGreatherThanOpr,
				m_pqxxResultOperators[i]["greatherthancmpop"].c_str(),
				oidOperatorFunc,
				m_pqxxResultOperators[i]["operproc"].c_str(),
				oidRestrictionFunc,
				m_pqxxResultOperators[i]["restrproc"].c_str(),
				oidJoinFunc,
				m_pqxxResultOperators[i]["joinproc"].c_str()
				);
    }
  }
  catch (const std::exception &e)
  {
    kdError() << e.what() << endl;
    KPGSqlDialog dlg(0, strQuery, e.what());
		dlg.exec();
    return false;
  } 
  
  return true;
}
void KPGOperatorsFolder::displayProperties(QWidget *widgetProperies)
{
	KPGPropertyPage *pPropertyPage = static_cast <KPGPropertyPage *> (widgetProperies);
  pPropertyPage->setLabelText(i18n("Operators &list:"));
	
	//----------------------------------------------------------------------------
	//Display operators list
	QTable *pTableOperators = pPropertyPage->m_pTableItems;
		
	// fill properties table with result data
	int nTableCols = fillPropertiesTable(m_pqxxResultOperators, pTableOperators);

  // field names
  QHeader* hHeader = pTableOperators->horizontalHeader();

  int nCol = 0;
	hHeader->setLabel(nCol++, i18n("Name"));
  hHeader->setLabel(nCol++, i18n("Description"));
	hHeader->setLabel(nCol++, i18n("Kind"));
  hHeader->setLabel(nCol++, i18n("Can Hash"));
	hHeader->setLabel(nCol++, i18n("Left Type"));
	hHeader->setLabel(nCol++, i18n("Right Type"));
	hHeader->setLabel(nCol++, i18n("Result Type"));
	hHeader->setLabel(nCol++, i18n("Comutator"));
	hHeader->setLabel(nCol++, i18n("Negator"));
	hHeader->setLabel(nCol++, i18n("Left-hand"));
	hHeader->setLabel(nCol++, i18n("Right-hand"));
	hHeader->setLabel(nCol++, i18n("Less-than"));
	hHeader->setLabel(nCol++, i18n("Greater-than"));
	hHeader->setLabel(nCol++, i18n("Function"));
	hHeader->setLabel(nCol++, i18n("Restriction func."));
	hHeader->setLabel(nCol++, i18n("Join func."));
	hHeader->setLabel(nCol++, i18n("Owner"));

  for(int nCol = 0; nCol < nTableCols; nCol++)
  {
    pTableOperators->adjustColumn(nCol);
  }
}

==> kpogre-1.5.2.tar.gz: kpogre-1.5.2/kpogre/DbObjects/kpgoperatorsfolder.cpp <==
//
// C++ Implementation: kpgoperatorsfolder
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgoperatorsfolder.h"

// include files for KDE
#include <kdebug.h>
#include <kmessagebox.h>
#include <klocale.h>

#include <qtable.h>

#include "kpgconnection.h"
#include "kpgschema.h"
#include "../PropertyPages/kpgpropertypage.h"
#include "kpgoperator.h"
#include "../kpgsqldialog.h"

KPGOperatorsFolder::KPGOperatorsFolder(KPGSchema *parent, pqxx::oid oidNameSpace)
 : KPGItemsFolder(parent, i18n("Operators"))
{
	setPixmap(0, *m_pIconFolderYellow);
	m_oidNameSpace = oidNameSpace;
}


KPGOperatorsFolder::~KPGOperatorsFolder()
{
}

bool KPGOperatorsFolder::refresh(pqxx::work &pqxxXaction)
{
  // delete all child items 
  while (QListViewItem * pItem = firstChild())
    delete pItem;

	// obtain list of operators
  QString strQuery("SELECT op.oid, op.oprname, description, op.oprkind, op.oprcanhash, op.oprleft, lt.typname as lefttype, op.oprright, rt.typname as righttype, op.oprresult, ret.typname as resulttype, op.oprcom, co.oprname as compop, op.oprnegate, ne.oprname as negop, op.oprlsortop, lso.oprname as leftsortop, op.oprrsortop, rso.oprname as rightsortop, op.oprltcmpop, lco.oprname as lessthancmpop, op.oprgtcmpop, gco.oprname as greatherthancmpop,  op.oprcode::oid AS oprcodeoid, op.oprcode as operproc, op.oprrest::oid AS oprrestoid, op.oprrest as restrproc, op.oprjoin::oid AS oprjoinoid, op.oprjoin as joinproc, pg_get_userbyid(op.oprowner) as opowner ");
		
	strQuery.append("FROM pg_catalog.pg_operator op ");
	strQuery.append("LEFT OUTER JOIN pg_catalog.pg_type lt ON lt.oid=op.oprleft ");
	strQuery.append("LEFT OUTER JOIN pg_catalog.pg_type rt ON rt.oid=op.oprright ");
	strQuery.append("JOIN pg_catalog.pg_type ret on ret.oid=op.oprresult ");
	strQuery.append("LEFT OUTER JOIN pg_catalog.pg_description des ON des.objoid=op.oid ");
	strQuery.append("LEFT OUTER JOIN pg_catalog.pg_operator co ON co.oid=op.oprcom ");
	strQuery.append("LEFT OUTER JOIN pg_catalog.pg_operator ne ON ne.oid=op.oprnegate ");
	strQuery.append("LEFT OUTER JOIN pg_catalog.pg_operator lso ON lso.oid=op.oprlsortop ");
	strQuery.append("LEFT OUTER JOIN pg_catalog.pg_operator rso ON rso.oid=op.oprrsortop ");
	strQuery.append("LEFT OUTER JOIN pg_catalog.pg_operator lco ON lco.oid=op.oprltcmpop ");
	strQuery.append("LEFT OUTER JOIN pg_catalog.pg_operator gco ON gco.oid=op.oprgtcmpop ");
	strQuery.append("WHERE op.oprnamespace = " + QString("%1").arg(m_oidNameSpace) + " ");
	strQuery.append("ORDER BY op.oprname");
			
  try
  {
    m_pqxxResultOperators = pqxxXaction.Exec(strQuery.latin1());

		KPGOperator *pgOperator = 0;
		
    for (result::size_type i = 0; i != m_pqxxResultOperators.size(); ++i)
    {
			pqxx::oid oid;
			m_pqxxResultOperators[i][0].to(oid);
		
			if(pgOperator == 0)
      	pgOperator = new KPGOperator(this, m_pqxxResultOperators[i]["oprname"].c_str(), oid);
			else
				pgOperator = new KPGOperator(this, pgOperator, m_pqxxResultOperators[i]["oprname"].c_str(), oid);
			
			bool bCanHash;
			pqxx::oid oidLeftType = 0;
			pqxx::oid oidRightType = 0;
			pqxx::oid oidResultType = 0;
			
			pqxx::oid oidComutatorOpr = 0;
			pqxx::oid oidNegatorOpr = 0;
			pqxx::oid oidLeftSortOpr = 0;
			pqxx::oid oidRightSortOpr = 0;
			pqxx::oid oidLessThanOpr = 0;
			pqxx::oid oidGreatherThanOpr = 0;
			
			pqxx::oid oidOperatorFunc = 0;
			pqxx::oid oidRestrictionFunc = 0;
			pqxx::oid oidJoinFunc = 0;
			
			m_pqxxResultOperators[i]["oprcanhash"].to(bCanHash);
			m_pqxxResultOperators[i]["oprleft"].to(oidLeftType);
			m_pqxxResultOperators[i]["oprright"].to(oidRightType);
			m_pqxxResultOperators[i]["oprresult"].to(oidResultType);
			
			m_pqxxResultOperators[i]["oprcom"].to(oidComutatorOpr);
			m_pqxxResultOperators[i]["oprnegate"].to(oidNegatorOpr);
			m_pqxxResultOperators[i]["oprlsortop"].to(oidLeftSortOpr);
			m_pqxxResultOperators[i]["oprrsortop"].to(oidRightSortOpr);
			m_pqxxResultOperators[i]["oprltcmpop"].to(oidLessThanOpr);
			m_pqxxResultOperators[i]["oprgtcmpop"].to(oidGreatherThanOpr);
			
			m_pqxxResultOperators[i]["oprcodeoid"].to(oidOperatorFunc);
			m_pqxxResultOperators[i]["oprrestoid"].to(oidRestrictionFunc);
			m_pqxxResultOperators[i]["oprjoinoid"].to(oidJoinFunc);
			
					
			pgOperator->setProperties(
				m_pqxxResultOperators[i]["description"].c_str(),
				m_pqxxResultOperators[i]["opowner"].c_str(),
				m_pqxxResultOperators[i]["oprkind"].c_str(),
				bCanHash,
				oidLeftType,
				m_pqxxResultOperators[i]["lefttype"].c_str(),
				oidRightType,
				m_pqxxResultOperators[i]["righttype"].c_str(),
				oidResultType,
				m_pqxxResultOperators[i]["resulttype"].c_str(),
				oidComutatorOpr,
				m_pqxxResultOperators[i]["compop"].c_str(),
				oidNegatorOpr,
				m_pqxxResultOperators[i]["negop"].c_str(),
				oidLeftSortOpr,
				m_pqxxResultOperators[i]["leftsortop"].c_str(),
				oidRightSortOpr,
				m_pqxxResultOperators[i]["rightsortop"].c_str(),
				oidLessThanOpr,
				m_pqxxResultOperators[i]["lessthancmpop"].c_str(),
				oidGreatherThanOpr,
				m_pqxxResultOperators[i]["greatherthancmpop"].c_str(),
				oidOperatorFunc,
				m_pqxxResultOperators[i]["operproc"].c_str(),
				oidRestrictionFunc,
				m_pqxxResultOperators[i]["restrproc"].c_str(),
				oidJoinFunc,
				m_pqxxResultOperators[i]["joinproc"].c_str()
				);
    }
  }
  catch (const std::exception &e)
  {
    kdError() << e.what() << endl;
    KPGSqlDialog dlg(0, strQuery, e.what());
		dlg.exec();
    return false;
  } 
  
  return true;
}
void KPGOperatorsFolder::displayProperties(QWidget *widgetProperies)
{
	if(widgetProperies == 0) return; // be defensive, user may close Properties window
	
	KPGPropertyPage *pPropertyPage = static_cast <KPGPropertyPage *> (widgetProperies);
  	pPropertyPage->setLabelText(i18n("Operators &list:"));
	
	//----------------------------------------------------------------------------
	//Display operators list
	QTable *pTableOperators = pPropertyPage->m_pTableItems;
		
	// fill properties table with result data
	int nTableCols = fillPropertiesTable(m_pqxxResultOperators, pTableOperators);

  // field names
  QHeader* hHeader = pTableOperators->horizontalHeader();

  int nCol = 0;
	hHeader->setLabel(nCol++, i18n("Name"));
  hHeader->setLabel(nCol++, i18n("Description"));
	hHeader->setLabel(nCol++, i18n("Kind"));
  hHeader->setLabel(nCol++, i18n("Can Hash"));
	hHeader->setLabel(nCol++, i18n("Left Type"));
	hHeader->setLabel(nCol++, i18n("Right Type"));
	hHeader->setLabel(nCol++, i18n("Result Type"));
	hHeader->setLabel(nCol++, i18n("Comutator"));
	hHeader->setLabel(nCol++, i18n("Negator"));
	hHeader->setLabel(nCol++, i18n("Left-hand"));
	hHeader->setLabel(nCol++, i18n("Right-hand"));
	hHeader->setLabel(nCol++, i18n("Less-than"));
	hHeader->setLabel(nCol++, i18n("Greater-than"));
	hHeader->setLabel(nCol++, i18n("Function"));
	hHeader->setLabel(nCol++, i18n("Restriction func."));
	hHeader->setLabel(nCol++, i18n("Join func."));
	hHeader->setLabel(nCol++, i18n("Owner"));

  for(int nCol = 0; nCol < nTableCols; nCol++)
  {
    pTableOperators->adjustColumn(nCol);
  }
}
